@@ -15,10 +15,17 @@ def juvare_send_task(text: str, to: str, event: int):
 
     with scope(organizer=event.organizer):
         client_secret = event.settings.juvare_client_secret  # global setting
-        if not client_secret:
+        url = (
+            event.settings.juvare_api_url or "https://notify.lab.juvare.com/manage/"
+        )  # global setting
+        if not (client_secret and url):
             return
-        to = to.replace(" ", "")
 
+        if url[-1] != "/":
+            url += "/"
+        url += "api/v3/notification"
+
+        to = to.replace(" ", "")
         if event.settings.juvare_text_signature:
             text = f"{text}\n\n{event.settings.juvare_text_signature}"
 
@@ -32,7 +39,7 @@ def juvare_send_task(text: str, to: str, event: int):
             }
         ]
         requests.post(
-            "https://notify.lab.juvare.com/manage/api/v3/notification",
+            url,
             data=json.dumps(body),
             headers={
                 "accept": "application/json",
